This is a package designed to allow te user to input a floating point value and convert it to any other unit.
The package can handle upwards of 1000 different units and uses api requests for up-to-date currency conversions.

Note: The conversions provided are accurate to at least one-thousandth, but there may be minimal error.
The currency conversion portion of this module cannot do all different currencies that are listed in chart.txt,
as this relies on the site that handles the api requests. Most common global currencies are supported.